linux-next: manual merge of the wireless-drivers-next tree with the wireless-drivers tree

From: Mark Brown
Date: Thu Oct 12 2017 - 13:14:48 EST


Hi all,

Today's linux-next merge of the wireless-drivers-next tree got a
conflict in:

drivers/net/wireless/intel/iwlwifi/iwl-nvm-parse.c

between commit:

44fd09dad5d2b78e ("iwlwifi: nvm: set the correct offsets to 3168 series")

from the wireless-drivers tree and commit:

a2ff48af65ad661a ("iwlwifi: remove redundant reading from NVM file")

from the wireless-drivers-next tree.

I fixed it up (see below) and can carry the fix as necessary. This
is now fixed as far as linux-next is concerned, but any non trivial
conflicts should be mentioned to your upstream maintainer when your tree
is submitted for merging. You may also want to consider cooperating
with the maintainer of the conflicting tree to minimise any particularly
complex conflicts.

diff --cc drivers/net/wireless/intel/iwlwifi/iwl-nvm-parse.c
index c3a5d8ccc95e,d9a2ea9dd93f..000000000000
--- a/drivers/net/wireless/intel/iwlwifi/iwl-nvm-parse.c
+++ b/drivers/net/wireless/intel/iwlwifi/iwl-nvm-parse.c
@@@ -75,9 -75,10 +75,10 @@@
#include "iwl-prph.h"
#include "iwl-io.h"
#include "iwl-csr.h"
+ #include "fw/acpi.h"

/* NVM offsets (in words) definitions */
-enum wkp_nvm_offsets {
+enum nvm_offsets {
/* NVM HW-Section offset (in words) definitions */
SUBSYSTEM_ID = 0x0A,
HW_ADDR = 0x15,
@@@ -89,13 -90,6 +90,9 @@@
SKU = 2,
N_HW_ADDRS = 3,
NVM_CHANNELS = 0x1E0 - NVM_SW_SECTION,
+
- /* NVM calibration section offset (in words) definitions */
- NVM_CALIB_SECTION = 0x2B8,
- XTAL_CALIB = 0x316 - NVM_CALIB_SECTION,
-
+ /* NVM REGULATORY -Section offset (in words) definitions */
+ NVM_CHANNELS_SDP = 0,
};

enum ext_nvm_offsets {
@@@ -758,15 -745,8 +755,12 @@@ iwl_parse_nvm_data(struct iwl_trans *tr
kfree(data);
return NULL;
}
+
+ ch_section = cfg->nvm_type == IWL_NVM_SDP ?
+ &regulatory[NVM_CHANNELS_SDP] :
+ &nvm_sw[NVM_CHANNELS];
+
- /* in family 8000 Xtal calibration values moved to OTP */
- data->xtal_calib[0] = *(nvm_calib + XTAL_CALIB);
- data->xtal_calib[1] = *(nvm_calib + XTAL_CALIB + 1);
lar_enabled = true;
- ch_section = &nvm_sw[NVM_CHANNELS];
} else {
u16 lar_offset = data->nvm_version < 0xE39 ?
NVM_LAR_OFFSET_OLD :

Attachment: signature.asc
Description: PGP signature